From 80d3f386d1d6a9417a3ba9610698e0cfae8a04a4 Mon Sep 17 00:00:00 2001
From: "Ilya.Kazakevich"
Date: Mon, 23 Mar 2015 19:28:54 +0300
Subject: [PATCH] "gnu" prefix removed from CommandLine classes according to
https://upsource.labs.intellij.net/idea-community/review/IDEA-COMMUNITY-CR-1732
---
.../CommandLineElementTypes.java | 4 ++--
.../CommandLineParser.java | 6 +++---
.../_CommandLineLexer.flex | 4 ++--
.../_CommandLineLexer.java | 10 +++++-----
.../psi/CommandLineArgument.java | 4 ++--
.../psi/CommandLineCommand.java | 4 ++--
.../psi/CommandLineOption.java | 4 ++--
.../psi/CommandLineVisitor.java | 4 ++--
.../psi/impl/CommandLineArgumentImpl.java | 8 ++++----
.../psi/impl/CommandLineCommandImpl.java | 8 ++++----
.../psi/impl/CommandLineOptionImpl.java | 8 ++++----
.../{gnu-command-line.xml => command-line.xml} | 18 +++++++++---------
python/src/META-INF/python-core.xml | 4 ++--
.../CommandLineArgumentReference.java | 4 ++--
.../CommandLineCommandReference.java | 6 +++---
.../CommandLineDocumentationProvider.java | 6 ++----
.../CommandLineElement.java | 4 ++--
.../CommandLineElementManipulator.java | 2 +-
.../CommandLineElementReference.java | 6 ++----
.../CommandLineElementType.java | 2 +-
.../CommandLineFileType.java | 2 +-
.../CommandLineFileTypeFactory.java | 2 +-
.../CommandLineInspection.java | 4 ++--
.../CommandLineLanguage.java | 2 +-
.../CommandLineOptionReference.java | 4 ++--
.../CommandLineParserDefinition.java | 6 +++---
.../CommandLineParserUtil.java | 2 +-
.../CommandLinePart.java | 4 ++--
.../CommandLineReferenceContributor.java | 4 ++--
.../CommandLineSyntaxHighlighterFactory.java | 2 +-
.../LookupWithIndentsBuilder.java | 2 +-
.../ValidationResult.java | 6 +++---
.../command_line.bnf | 18 +++++++++---------
.../package-info.java | 8 ++++----
.../psi/CommandLineFile.java | 8 ++++----
.../psi/ValidationResultImpl.java | 4 ++--
.../psi/impl/CommandLinePsiImplUtils.java | 12 ++++++------
.../psi/impl/package-info.java | 4 ++--
.../psi/package-info.java | 2 +-
.../console/ArgumentHintLayer.java | 4 ++--
.../console/CommandExecutor.java | 4 ++--
.../console/CommandLineConsole.java | 4 ++--
.../commandInterface/package-info.java | 6 +++---
.../CommandLineArgsTest.java | 4 ++--
.../CommandLineInspectionTest.java | 4 ++--
.../CommandLineParserTest.java | 4 +---
.../CommandLineSuggestionTest.java | 2 +-
.../CommandTestTools.java | 4 ++--
48 files changed, 121 insertions(+), 127 deletions(-)
rename python/gen/com/jetbrains/commandInterface/{gnuCommandLine => commandLine}/CommandLineElementTypes.java (91%)
rename python/gen/com/jetbrains/commandInterface/{gnuCommandLine => commandLine}/CommandLineParser.java (95%)
rename python/gen/com/jetbrains/commandInterface/{gnuCommandLine => commandLine}/_CommandLineLexer.flex (88%)
rename python/gen/com/jetbrains/commandInterface/{gnuCommandLine => commandLine}/_CommandLineLexer.java (97%)
rename python/gen/com/jetbrains/commandInterface/{gnuCommandLine => commandLine}/psi/CommandLineArgument.java (81%)
rename python/gen/com/jetbrains/commandInterface/{gnuCommandLine => commandLine}/psi/CommandLineCommand.java (68%)
rename python/gen/com/jetbrains/commandInterface/{gnuCommandLine => commandLine}/psi/CommandLineOption.java (79%)
rename python/gen/com/jetbrains/commandInterface/{gnuCommandLine => commandLine}/psi/CommandLineVisitor.java (83%)
rename python/gen/com/jetbrains/commandInterface/{gnuCommandLine => commandLine}/psi/impl/CommandLineArgumentImpl.java (82%)
rename python/gen/com/jetbrains/commandInterface/{gnuCommandLine => commandLine}/psi/impl/CommandLineCommandImpl.java (73%)
rename python/gen/com/jetbrains/commandInterface/{gnuCommandLine => commandLine}/psi/impl/CommandLineOptionImpl.java (81%)
rename python/src/META-INF/{gnu-command-line.xml => command-line.xml} (67%)
rename python/src/com/jetbrains/commandInterface/{gnuCommandLine => commandLine}/CommandLineArgumentReference.java (94%)
rename python/src/com/jetbrains/commandInterface/{gnuCommandLine => commandLine}/CommandLineCommandReference.java (90%)
rename python/src/com/jetbrains/commandInterface/{gnuCommandLine => commandLine}/CommandLineDocumentationProvider.java (94%)
rename python/src/com/jetbrains/commandInterface/{gnuCommandLine => commandLine}/CommandLineElement.java (93%)
rename python/src/com/jetbrains/commandInterface/{gnuCommandLine => commandLine}/CommandLineElementManipulator.java (95%)
rename python/src/com/jetbrains/commandInterface/{gnuCommandLine => commandLine}/CommandLineElementReference.java (92%)
rename python/src/com/jetbrains/commandInterface/{gnuCommandLine => commandLine}/CommandLineElementType.java (94%)
rename python/src/com/jetbrains/commandInterface/{gnuCommandLine => commandLine}/CommandLineFileType.java (96%)
rename python/src/com/jetbrains/commandInterface/{gnuCommandLine => commandLine}/CommandLineFileTypeFactory.java (95%)
rename python/src/com/jetbrains/commandInterface/{gnuCommandLine => commandLine}/CommandLineInspection.java (97%)
rename python/src/com/jetbrains/commandInterface/{gnuCommandLine => commandLine}/CommandLineLanguage.java (94%)
rename python/src/com/jetbrains/commandInterface/{gnuCommandLine => commandLine}/CommandLineOptionReference.java (93%)
rename python/src/com/jetbrains/commandInterface/{gnuCommandLine => commandLine}/CommandLineParserDefinition.java (91%)
rename python/src/com/jetbrains/commandInterface/{gnuCommandLine => commandLine}/CommandLineParserUtil.java (97%)
rename python/src/com/jetbrains/commandInterface/{gnuCommandLine => commandLine}/CommandLinePart.java (90%)
rename python/src/com/jetbrains/commandInterface/{gnuCommandLine => commandLine}/CommandLineReferenceContributor.java (94%)
rename python/src/com/jetbrains/commandInterface/{gnuCommandLine => commandLine}/CommandLineSyntaxHighlighterFactory.java (98%)
rename python/src/com/jetbrains/commandInterface/{gnuCommandLine => commandLine}/LookupWithIndentsBuilder.java (98%)
rename python/src/com/jetbrains/commandInterface/{gnuCommandLine => commandLine}/ValidationResult.java (92%)
rename python/src/com/jetbrains/commandInterface/{gnuCommandLine => commandLine}/command_line.bnf (68%)
rename python/src/com/jetbrains/commandInterface/{gnuCommandLine => commandLine}/package-info.java (81%)
rename python/src/com/jetbrains/commandInterface/{gnuCommandLine => commandLine}/psi/CommandLineFile.java (92%)
rename python/src/com/jetbrains/commandInterface/{gnuCommandLine => commandLine}/psi/ValidationResultImpl.java (98%)
rename python/src/com/jetbrains/commandInterface/{gnuCommandLine => commandLine}/psi/impl/CommandLinePsiImplUtils.java (91%)
rename python/src/com/jetbrains/commandInterface/{gnuCommandLine => commandLine}/psi/impl/package-info.java (86%)
rename python/src/com/jetbrains/commandInterface/{gnuCommandLine => commandLine}/psi/package-info.java (93%)
rename python/testSrc/com/jetbrains/commandInterface/{gnuCommandLine => commandLine}/CommandLineArgsTest.java (95%)
rename python/testSrc/com/jetbrains/commandInterface/{gnuCommandLine => commandLine}/CommandLineInspectionTest.java (93%)
rename python/testSrc/com/jetbrains/commandInterface/{gnuCommandLine => commandLine}/CommandLineParserTest.java (93%)
rename python/testSrc/com/jetbrains/commandInterface/{gnuCommandLine => commandLine}/CommandLineSuggestionTest.java (97%)
rename python/testSrc/com/jetbrains/commandInterface/{gnuCommandLine => commandLine}/CommandTestTools.java (96%)
diff --git a/python/gen/com/jetbrains/commandInterface/gnuCommandLine/CommandLineElementTypes.java b/python/gen/com/jetbrains/commandInterface/commandLine/CommandLineElementTypes.java
similarity index 91%
rename from python/gen/com/jetbrains/commandInterface/gnuCommandLine/CommandLineElementTypes.java
rename to python/gen/com/jetbrains/commandInterface/commandLine/CommandLineElementTypes.java
index d54609b4a048..1d2895b7c123 100644
--- a/python/gen/com/jetbrains/commandInterface/gnuCommandLine/CommandLineElementTypes.java
+++ b/python/gen/com/jetbrains/commandInterface/commandLine/CommandLineElementTypes.java
@@ -1,10 +1,10 @@
// This is a generated file. Not intended for manual editing.
-package com.jetbrains.commandInterface.gnuCommandLine;
+package com.jetbrains.commandInterface.commandLine;
import com.intellij.psi.tree.IElementType;
import com.intellij.psi.PsiElement;
import com.intellij.lang.ASTNode;
-import com.jetbrains.commandInterface.gnuCommandLine.psi.impl.*;
+import com.jetbrains.commandInterface.commandLine.psi.impl.*;
public interface CommandLineElementTypes {
diff --git a/python/gen/com/jetbrains/commandInterface/gnuCommandLine/CommandLineParser.java b/python/gen/com/jetbrains/commandInterface/commandLine/CommandLineParser.java
similarity index 95%
rename from python/gen/com/jetbrains/commandInterface/gnuCommandLine/CommandLineParser.java
rename to python/gen/com/jetbrains/commandInterface/commandLine/CommandLineParser.java
index 157d84db3c92..19f9c4e3071a 100644
--- a/python/gen/com/jetbrains/commandInterface/gnuCommandLine/CommandLineParser.java
+++ b/python/gen/com/jetbrains/commandInterface/commandLine/CommandLineParser.java
@@ -1,10 +1,10 @@
// This is a generated file. Not intended for manual editing.
-package com.jetbrains.commandInterface.gnuCommandLine;
+package com.jetbrains.commandInterface.commandLine;
import com.intellij.lang.PsiBuilder;
import com.intellij.lang.PsiBuilder.Marker;
-import static com.jetbrains.commandInterface.gnuCommandLine.CommandLineElementTypes.*;
-import static com.jetbrains.commandInterface.gnuCommandLine.CommandLineParserUtil.*;
+import static com.jetbrains.commandInterface.commandLine.CommandLineElementTypes.*;
+import static com.jetbrains.commandInterface.commandLine.CommandLineParserUtil.*;
import com.intellij.psi.tree.IElementType;
import com.intellij.lang.ASTNode;
import com.intellij.psi.tree.TokenSet;
diff --git a/python/gen/com/jetbrains/commandInterface/gnuCommandLine/_CommandLineLexer.flex b/python/gen/com/jetbrains/commandInterface/commandLine/_CommandLineLexer.flex
similarity index 88%
rename from python/gen/com/jetbrains/commandInterface/gnuCommandLine/_CommandLineLexer.flex
rename to python/gen/com/jetbrains/commandInterface/commandLine/_CommandLineLexer.flex
index c242cf062d49..e15ed5cd64f4 100644
--- a/python/gen/com/jetbrains/commandInterface/gnuCommandLine/_CommandLineLexer.flex
+++ b/python/gen/com/jetbrains/commandInterface/commandLine/_CommandLineLexer.flex
@@ -1,7 +1,7 @@
-package com.jetbrains.commandInterface.gnuCommandLine;
+package com.jetbrains.commandInterface.commandLine;
import com.intellij.lexer.*;
import com.intellij.psi.tree.IElementType;
-import static com.jetbrains.commandInterface.gnuCommandLine.CommandLineElementTypes.*;
+import static com.jetbrains.commandInterface.commandLine.CommandLineElementTypes.*;
%%
diff --git a/python/gen/com/jetbrains/commandInterface/gnuCommandLine/_CommandLineLexer.java b/python/gen/com/jetbrains/commandInterface/commandLine/_CommandLineLexer.java
similarity index 97%
rename from python/gen/com/jetbrains/commandInterface/gnuCommandLine/_CommandLineLexer.java
rename to python/gen/com/jetbrains/commandInterface/commandLine/_CommandLineLexer.java
index 90d9b3af67c6..d6332577ad93 100644
--- a/python/gen/com/jetbrains/commandInterface/gnuCommandLine/_CommandLineLexer.java
+++ b/python/gen/com/jetbrains/commandInterface/commandLine/_CommandLineLexer.java
@@ -1,16 +1,16 @@
-/* The following code was generated by JFlex 1.4.3 on 12.03.15 21:27 */
+/* The following code was generated by JFlex 1.4.3 on 23.03.15 20:24 */
-package com.jetbrains.commandInterface.gnuCommandLine;
+package com.jetbrains.commandInterface.commandLine;
import com.intellij.lexer.*;
import com.intellij.psi.tree.IElementType;
-import static com.jetbrains.commandInterface.gnuCommandLine.CommandLineElementTypes.*;
+import static com.jetbrains.commandInterface.commandLine.CommandLineElementTypes.*;
/**
* This class is a scanner generated by
* JFlex 1.4.3
- * on 12.03.15 21:27 from the specification file
- * C:/work/ultimate/community/python/gen/com/jetbrains/commandInterface/gnuCommandLine/_CommandLineLexer.flex
+ * on 23.03.15 20:24 from the specification file
+ * C:/Users/ilya.kazakevich/work/ultimate/community/python/gen/com/jetbrains/commandInterface/commandLine/_CommandLineLexer.flex
*/
public class _CommandLineLexer implements FlexLexer {
/** initial size of the lookahead buffer */
diff --git a/python/gen/com/jetbrains/commandInterface/gnuCommandLine/psi/CommandLineArgument.java b/python/gen/com/jetbrains/commandInterface/commandLine/psi/CommandLineArgument.java
similarity index 81%
rename from python/gen/com/jetbrains/commandInterface/gnuCommandLine/psi/CommandLineArgument.java
rename to python/gen/com/jetbrains/commandInterface/commandLine/psi/CommandLineArgument.java
index de7928af0179..1bae201e6ba5 100644
--- a/python/gen/com/jetbrains/commandInterface/gnuCommandLine/psi/CommandLineArgument.java
+++ b/python/gen/com/jetbrains/commandInterface/commandLine/psi/CommandLineArgument.java
@@ -1,10 +1,10 @@
// This is a generated file. Not intended for manual editing.
-package com.jetbrains.commandInterface.gnuCommandLine.psi;
+package com.jetbrains.commandInterface.commandLine.psi;
import java.util.List;
import org.jetbrains.annotations.*;
import com.intellij.psi.PsiElement;
-import com.jetbrains.commandInterface.gnuCommandLine.CommandLinePart;
+import com.jetbrains.commandInterface.commandLine.CommandLinePart;
import com.jetbrains.commandInterface.command.Argument;
import com.jetbrains.commandInterface.command.Option;
diff --git a/python/gen/com/jetbrains/commandInterface/gnuCommandLine/psi/CommandLineCommand.java b/python/gen/com/jetbrains/commandInterface/commandLine/psi/CommandLineCommand.java
similarity index 68%
rename from python/gen/com/jetbrains/commandInterface/gnuCommandLine/psi/CommandLineCommand.java
rename to python/gen/com/jetbrains/commandInterface/commandLine/psi/CommandLineCommand.java
index c76fae48e276..3e925f19591c 100644
--- a/python/gen/com/jetbrains/commandInterface/gnuCommandLine/psi/CommandLineCommand.java
+++ b/python/gen/com/jetbrains/commandInterface/commandLine/psi/CommandLineCommand.java
@@ -1,10 +1,10 @@
// This is a generated file. Not intended for manual editing.
-package com.jetbrains.commandInterface.gnuCommandLine.psi;
+package com.jetbrains.commandInterface.commandLine.psi;
import java.util.List;
import org.jetbrains.annotations.*;
import com.intellij.psi.PsiElement;
-import com.jetbrains.commandInterface.gnuCommandLine.CommandLinePart;
+import com.jetbrains.commandInterface.commandLine.CommandLinePart;
public interface CommandLineCommand extends CommandLinePart {
diff --git a/python/gen/com/jetbrains/commandInterface/gnuCommandLine/psi/CommandLineOption.java b/python/gen/com/jetbrains/commandInterface/commandLine/psi/CommandLineOption.java
similarity index 79%
rename from python/gen/com/jetbrains/commandInterface/gnuCommandLine/psi/CommandLineOption.java
rename to python/gen/com/jetbrains/commandInterface/commandLine/psi/CommandLineOption.java
index 3111389b8aa0..467fb4a9a3f8 100644
--- a/python/gen/com/jetbrains/commandInterface/gnuCommandLine/psi/CommandLineOption.java
+++ b/python/gen/com/jetbrains/commandInterface/commandLine/psi/CommandLineOption.java
@@ -1,10 +1,10 @@
// This is a generated file. Not intended for manual editing.
-package com.jetbrains.commandInterface.gnuCommandLine.psi;
+package com.jetbrains.commandInterface.commandLine.psi;
import java.util.List;
import org.jetbrains.annotations.*;
import com.intellij.psi.PsiElement;
-import com.jetbrains.commandInterface.gnuCommandLine.CommandLinePart;
+import com.jetbrains.commandInterface.commandLine.CommandLinePart;
import com.jetbrains.commandInterface.command.Option;
public interface CommandLineOption extends CommandLinePart {
diff --git a/python/gen/com/jetbrains/commandInterface/gnuCommandLine/psi/CommandLineVisitor.java b/python/gen/com/jetbrains/commandInterface/commandLine/psi/CommandLineVisitor.java
similarity index 83%
rename from python/gen/com/jetbrains/commandInterface/gnuCommandLine/psi/CommandLineVisitor.java
rename to python/gen/com/jetbrains/commandInterface/commandLine/psi/CommandLineVisitor.java
index a4427ee344f0..b0bf2caa071c 100644
--- a/python/gen/com/jetbrains/commandInterface/gnuCommandLine/psi/CommandLineVisitor.java
+++ b/python/gen/com/jetbrains/commandInterface/commandLine/psi/CommandLineVisitor.java
@@ -1,10 +1,10 @@
// This is a generated file. Not intended for manual editing.
-package com.jetbrains.commandInterface.gnuCommandLine.psi;
+package com.jetbrains.commandInterface.commandLine.psi;
import org.jetbrains.annotations.*;
import com.intellij.psi.PsiElementVisitor;
import com.intellij.psi.PsiElement;
-import com.jetbrains.commandInterface.gnuCommandLine.CommandLinePart;
+import com.jetbrains.commandInterface.commandLine.CommandLinePart;
public class CommandLineVisitor extends PsiElementVisitor {
diff --git a/python/gen/com/jetbrains/commandInterface/gnuCommandLine/psi/impl/CommandLineArgumentImpl.java b/python/gen/com/jetbrains/commandInterface/commandLine/psi/impl/CommandLineArgumentImpl.java
similarity index 82%
rename from python/gen/com/jetbrains/commandInterface/gnuCommandLine/psi/impl/CommandLineArgumentImpl.java
rename to python/gen/com/jetbrains/commandInterface/commandLine/psi/impl/CommandLineArgumentImpl.java
index 19a12dab005f..555d78259a6b 100644
--- a/python/gen/com/jetbrains/commandInterface/gnuCommandLine/psi/impl/CommandLineArgumentImpl.java
+++ b/python/gen/com/jetbrains/commandInterface/commandLine/psi/impl/CommandLineArgumentImpl.java
@@ -1,5 +1,5 @@
// This is a generated file. Not intended for manual editing.
-package com.jetbrains.commandInterface.gnuCommandLine.psi.impl;
+package com.jetbrains.commandInterface.commandLine.psi.impl;
import java.util.List;
import org.jetbrains.annotations.*;
@@ -7,9 +7,9 @@ import com.intellij.lang.ASTNode;
import com.intellij.psi.PsiElement;
import com.intellij.psi.PsiElementVisitor;
import com.intellij.psi.util.PsiTreeUtil;
-import static com.jetbrains.commandInterface.gnuCommandLine.CommandLineElementTypes.*;
-import com.jetbrains.commandInterface.gnuCommandLine.CommandLineElement;
-import com.jetbrains.commandInterface.gnuCommandLine.psi.*;
+import static com.jetbrains.commandInterface.commandLine.CommandLineElementTypes.*;
+import com.jetbrains.commandInterface.commandLine.CommandLineElement;
+import com.jetbrains.commandInterface.commandLine.psi.*;
import com.jetbrains.commandInterface.command.Argument;
import com.jetbrains.commandInterface.command.Option;
diff --git a/python/gen/com/jetbrains/commandInterface/gnuCommandLine/psi/impl/CommandLineCommandImpl.java b/python/gen/com/jetbrains/commandInterface/commandLine/psi/impl/CommandLineCommandImpl.java
similarity index 73%
rename from python/gen/com/jetbrains/commandInterface/gnuCommandLine/psi/impl/CommandLineCommandImpl.java
rename to python/gen/com/jetbrains/commandInterface/commandLine/psi/impl/CommandLineCommandImpl.java
index 10f491a82366..bcd0e883f0bc 100644
--- a/python/gen/com/jetbrains/commandInterface/gnuCommandLine/psi/impl/CommandLineCommandImpl.java
+++ b/python/gen/com/jetbrains/commandInterface/commandLine/psi/impl/CommandLineCommandImpl.java
@@ -1,5 +1,5 @@
// This is a generated file. Not intended for manual editing.
-package com.jetbrains.commandInterface.gnuCommandLine.psi.impl;
+package com.jetbrains.commandInterface.commandLine.psi.impl;
import java.util.List;
import org.jetbrains.annotations.*;
@@ -7,9 +7,9 @@ import com.intellij.lang.ASTNode;
import com.intellij.psi.PsiElement;
import com.intellij.psi.PsiElementVisitor;
import com.intellij.psi.util.PsiTreeUtil;
-import static com.jetbrains.commandInterface.gnuCommandLine.CommandLineElementTypes.*;
-import com.jetbrains.commandInterface.gnuCommandLine.CommandLineElement;
-import com.jetbrains.commandInterface.gnuCommandLine.psi.*;
+import static com.jetbrains.commandInterface.commandLine.CommandLineElementTypes.*;
+import com.jetbrains.commandInterface.commandLine.CommandLineElement;
+import com.jetbrains.commandInterface.commandLine.psi.*;
public class CommandLineCommandImpl extends CommandLineElement implements CommandLineCommand {
diff --git a/python/gen/com/jetbrains/commandInterface/gnuCommandLine/psi/impl/CommandLineOptionImpl.java b/python/gen/com/jetbrains/commandInterface/commandLine/psi/impl/CommandLineOptionImpl.java
similarity index 81%
rename from python/gen/com/jetbrains/commandInterface/gnuCommandLine/psi/impl/CommandLineOptionImpl.java
rename to python/gen/com/jetbrains/commandInterface/commandLine/psi/impl/CommandLineOptionImpl.java
index 823d51473504..919c39e2df7d 100644
--- a/python/gen/com/jetbrains/commandInterface/gnuCommandLine/psi/impl/CommandLineOptionImpl.java
+++ b/python/gen/com/jetbrains/commandInterface/commandLine/psi/impl/CommandLineOptionImpl.java
@@ -1,5 +1,5 @@
// This is a generated file. Not intended for manual editing.
-package com.jetbrains.commandInterface.gnuCommandLine.psi.impl;
+package com.jetbrains.commandInterface.commandLine.psi.impl;
import java.util.List;
import org.jetbrains.annotations.*;
@@ -7,9 +7,9 @@ import com.intellij.lang.ASTNode;
import com.intellij.psi.PsiElement;
import com.intellij.psi.PsiElementVisitor;
import com.intellij.psi.util.PsiTreeUtil;
-import static com.jetbrains.commandInterface.gnuCommandLine.CommandLineElementTypes.*;
-import com.jetbrains.commandInterface.gnuCommandLine.CommandLineElement;
-import com.jetbrains.commandInterface.gnuCommandLine.psi.*;
+import static com.jetbrains.commandInterface.commandLine.CommandLineElementTypes.*;
+import com.jetbrains.commandInterface.commandLine.CommandLineElement;
+import com.jetbrains.commandInterface.commandLine.psi.*;
import com.jetbrains.commandInterface.command.Option;
public class CommandLineOptionImpl extends CommandLineElement implements CommandLineOption {
diff --git a/python/src/META-INF/gnu-command-line.xml b/python/src/META-INF/command-line.xml
similarity index 67%
rename from python/src/META-INF/gnu-command-line.xml
rename to python/src/META-INF/command-line.xml
index fe41c5b9f616..93c8a2d5c504 100644
--- a/python/src/META-INF/gnu-command-line.xml
+++ b/python/src/META-INF/command-line.xml
@@ -2,25 +2,25 @@
-
+
+ implementationClass="com.jetbrains.commandInterface.commandLine.CommandLineParserDefinition"/>
-
-
+ implementationClass="com.jetbrains.commandInterface.commandLine.CommandLineSyntaxHighlighterFactory"/>
+
+
+ implementationClass="com.jetbrains.commandInterface.commandLine.CommandLineInspection"/>
+ implementationClass="com.jetbrains.commandInterface.commandLine.CommandLineDocumentationProvider"/>
\ No newline at end of file
diff --git a/python/src/META-INF/python-core.xml b/python/src/META-INF/python-core.xml
index 5e4a1951c0c7..ec55ef71746a 100644
--- a/python/src/META-INF/python-core.xml
+++ b/python/src/META-INF/python-core.xml
@@ -6,8 +6,8 @@
-
-
+
+
diff --git a/python/src/com/jetbrains/commandInterface/gnuCommandLine/CommandLineArgumentReference.java b/python/src/com/jetbrains/commandInterface/commandLine/CommandLineArgumentReference.java
similarity index 94%
rename from python/src/com/jetbrains/commandInterface/gnuCommandLine/CommandLineArgumentReference.java
rename to python/src/com/jetbrains/commandInterface/commandLine/CommandLineArgumentReference.java
index bc532050f185..9e2c0e76fce3 100644
--- a/python/src/com/jetbrains/commandInterface/gnuCommandLine/CommandLineArgumentReference.java
+++ b/python/src/com/jetbrains/commandInterface/commandLine/CommandLineArgumentReference.java
@@ -13,13 +13,13 @@
* See the License for the specific language governing permissions and
* limitations under the License.
*/
-package com.jetbrains.commandInterface.gnuCommandLine;
+package com.jetbrains.commandInterface.commandLine;
import com.intellij.codeInsight.lookup.LookupElementBuilder;
import com.intellij.psi.PsiElement;
import com.jetbrains.commandInterface.command.Argument;
import com.jetbrains.commandInterface.command.Option;
-import com.jetbrains.commandInterface.gnuCommandLine.psi.CommandLineArgument;
+import com.jetbrains.commandInterface.commandLine.psi.CommandLineArgument;
import org.jetbrains.annotations.NotNull;
import org.jetbrains.annotations.Nullable;
diff --git a/python/src/com/jetbrains/commandInterface/gnuCommandLine/CommandLineCommandReference.java b/python/src/com/jetbrains/commandInterface/commandLine/CommandLineCommandReference.java
similarity index 90%
rename from python/src/com/jetbrains/commandInterface/gnuCommandLine/CommandLineCommandReference.java
rename to python/src/com/jetbrains/commandInterface/commandLine/CommandLineCommandReference.java
index 71ee5adfe9d7..ddf220258872 100644
--- a/python/src/com/jetbrains/commandInterface/gnuCommandLine/CommandLineCommandReference.java
+++ b/python/src/com/jetbrains/commandInterface/commandLine/CommandLineCommandReference.java
@@ -13,13 +13,13 @@
* See the License for the specific language governing permissions and
* limitations under the License.
*/
-package com.jetbrains.commandInterface.gnuCommandLine;
+package com.jetbrains.commandInterface.commandLine;
import com.intellij.codeInsight.lookup.LookupElementBuilder;
import com.intellij.psi.PsiElement;
import com.jetbrains.commandInterface.command.Command;
-import com.jetbrains.commandInterface.gnuCommandLine.psi.CommandLineCommand;
-import com.jetbrains.commandInterface.gnuCommandLine.psi.CommandLineFile;
+import com.jetbrains.commandInterface.commandLine.psi.CommandLineCommand;
+import com.jetbrains.commandInterface.commandLine.psi.CommandLineFile;
import org.jetbrains.annotations.NotNull;
import org.jetbrains.annotations.Nullable;
diff --git a/python/src/com/jetbrains/commandInterface/gnuCommandLine/CommandLineDocumentationProvider.java b/python/src/com/jetbrains/commandInterface/commandLine/CommandLineDocumentationProvider.java
similarity index 94%
rename from python/src/com/jetbrains/commandInterface/gnuCommandLine/CommandLineDocumentationProvider.java
rename to python/src/com/jetbrains/commandInterface/commandLine/CommandLineDocumentationProvider.java
index 617c884f19ee..64957fca9d2a 100644
--- a/python/src/com/jetbrains/commandInterface/gnuCommandLine/CommandLineDocumentationProvider.java
+++ b/python/src/com/jetbrains/commandInterface/commandLine/CommandLineDocumentationProvider.java
@@ -13,19 +13,17 @@
* See the License for the specific language governing permissions and
* limitations under the License.
*/
-package com.jetbrains.commandInterface.gnuCommandLine;
+package com.jetbrains.commandInterface.commandLine;
import com.intellij.lang.documentation.DocumentationProviderEx;
import com.intellij.openapi.editor.Editor;
-import com.intellij.openapi.util.Ref;
import com.intellij.openapi.util.text.StringUtil;
import com.intellij.psi.PsiElement;
import com.intellij.psi.PsiFile;
import com.intellij.psi.util.PsiTreeUtil;
-import com.jetbrains.commandInterface.command.Argument;
import com.jetbrains.commandInterface.command.Command;
import com.jetbrains.commandInterface.command.Option;
-import com.jetbrains.commandInterface.gnuCommandLine.psi.*;
+import com.jetbrains.commandInterface.commandLine.psi.*;
import com.jetbrains.python.psi.PyUtil;
import org.jetbrains.annotations.NotNull;
import org.jetbrains.annotations.Nullable;
diff --git a/python/src/com/jetbrains/commandInterface/gnuCommandLine/CommandLineElement.java b/python/src/com/jetbrains/commandInterface/commandLine/CommandLineElement.java
similarity index 93%
rename from python/src/com/jetbrains/commandInterface/gnuCommandLine/CommandLineElement.java
rename to python/src/com/jetbrains/commandInterface/commandLine/CommandLineElement.java
index faa6c5ec3b48..c4373c5f7cc6 100644
--- a/python/src/com/jetbrains/commandInterface/gnuCommandLine/CommandLineElement.java
+++ b/python/src/com/jetbrains/commandInterface/commandLine/CommandLineElement.java
@@ -13,7 +13,7 @@
* See the License for the specific language governing permissions and
* limitations under the License.
*/
-package com.jetbrains.commandInterface.gnuCommandLine;
+package com.jetbrains.commandInterface.commandLine;
import com.intellij.extapi.psi.ASTWrapperPsiElement;
import com.intellij.lang.ASTNode;
@@ -21,7 +21,7 @@ import com.intellij.psi.PsiReference;
import com.intellij.psi.impl.source.resolve.reference.ReferenceProvidersRegistry;
import com.intellij.psi.util.PsiTreeUtil;
import com.jetbrains.commandInterface.command.Command;
-import com.jetbrains.commandInterface.gnuCommandLine.psi.CommandLineFile;
+import com.jetbrains.commandInterface.commandLine.psi.CommandLineFile;
import org.jetbrains.annotations.NotNull;
import org.jetbrains.annotations.Nullable;
diff --git a/python/src/com/jetbrains/commandInterface/gnuCommandLine/CommandLineElementManipulator.java b/python/src/com/jetbrains/commandInterface/commandLine/CommandLineElementManipulator.java
similarity index 95%
rename from python/src/com/jetbrains/commandInterface/gnuCommandLine/CommandLineElementManipulator.java
rename to python/src/com/jetbrains/commandInterface/commandLine/CommandLineElementManipulator.java
index 29794f0dfb65..e97ed2cbb39c 100644
--- a/python/src/com/jetbrains/commandInterface/gnuCommandLine/CommandLineElementManipulator.java
+++ b/python/src/com/jetbrains/commandInterface/commandLine/CommandLineElementManipulator.java
@@ -13,7 +13,7 @@
* See the License for the specific language governing permissions and
* limitations under the License.
*/
-package com.jetbrains.commandInterface.gnuCommandLine;
+package com.jetbrains.commandInterface.commandLine;
import com.intellij.openapi.util.TextRange;
import com.intellij.psi.AbstractElementManipulator;
diff --git a/python/src/com/jetbrains/commandInterface/gnuCommandLine/CommandLineElementReference.java b/python/src/com/jetbrains/commandInterface/commandLine/CommandLineElementReference.java
similarity index 92%
rename from python/src/com/jetbrains/commandInterface/gnuCommandLine/CommandLineElementReference.java
rename to python/src/com/jetbrains/commandInterface/commandLine/CommandLineElementReference.java
index 718ced07423e..939c34b88f43 100644
--- a/python/src/com/jetbrains/commandInterface/gnuCommandLine/CommandLineElementReference.java
+++ b/python/src/com/jetbrains/commandInterface/commandLine/CommandLineElementReference.java
@@ -13,18 +13,16 @@
* See the License for the specific language governing permissions and
* limitations under the License.
*/
-package com.jetbrains.commandInterface.gnuCommandLine;
+package com.jetbrains.commandInterface.commandLine;
import com.intellij.psi.PsiElement;
import com.intellij.psi.PsiReferenceBase;
import com.intellij.psi.util.PsiTreeUtil;
import com.jetbrains.commandInterface.command.Command;
-import com.jetbrains.commandInterface.gnuCommandLine.psi.CommandLineFile;
+import com.jetbrains.commandInterface.commandLine.psi.CommandLineFile;
import org.jetbrains.annotations.NotNull;
import org.jetbrains.annotations.Nullable;
-import java.util.List;
-
/**
* Parent of all references injected to command line elements
*
diff --git a/python/src/com/jetbrains/commandInterface/gnuCommandLine/CommandLineElementType.java b/python/src/com/jetbrains/commandInterface/commandLine/CommandLineElementType.java
similarity index 94%
rename from python/src/com/jetbrains/commandInterface/gnuCommandLine/CommandLineElementType.java
rename to python/src/com/jetbrains/commandInterface/commandLine/CommandLineElementType.java
index 9ec25beadd31..2cb1bee8db18 100644
--- a/python/src/com/jetbrains/commandInterface/gnuCommandLine/CommandLineElementType.java
+++ b/python/src/com/jetbrains/commandInterface/commandLine/CommandLineElementType.java
@@ -13,7 +13,7 @@
* See the License for the specific language governing permissions and
* limitations under the License.
*/
-package com.jetbrains.commandInterface.gnuCommandLine;
+package com.jetbrains.commandInterface.commandLine;
import com.intellij.psi.tree.IElementType;
import org.jetbrains.annotations.NonNls;
diff --git a/python/src/com/jetbrains/commandInterface/gnuCommandLine/CommandLineFileType.java b/python/src/com/jetbrains/commandInterface/commandLine/CommandLineFileType.java
similarity index 96%
rename from python/src/com/jetbrains/commandInterface/gnuCommandLine/CommandLineFileType.java
rename to python/src/com/jetbrains/commandInterface/commandLine/CommandLineFileType.java
index a93020649844..7d8de96dda50 100644
--- a/python/src/com/jetbrains/commandInterface/gnuCommandLine/CommandLineFileType.java
+++ b/python/src/com/jetbrains/commandInterface/commandLine/CommandLineFileType.java
@@ -13,7 +13,7 @@
* See the License for the specific language governing permissions and
* limitations under the License.
*/
-package com.jetbrains.commandInterface.gnuCommandLine;
+package com.jetbrains.commandInterface.commandLine;
import com.intellij.openapi.fileTypes.FileType;
import com.intellij.openapi.fileTypes.LanguageFileType;
diff --git a/python/src/com/jetbrains/commandInterface/gnuCommandLine/CommandLineFileTypeFactory.java b/python/src/com/jetbrains/commandInterface/commandLine/CommandLineFileTypeFactory.java
similarity index 95%
rename from python/src/com/jetbrains/commandInterface/gnuCommandLine/CommandLineFileTypeFactory.java
rename to python/src/com/jetbrains/commandInterface/commandLine/CommandLineFileTypeFactory.java
index 998a6ff82cde..0cd4510bffe4 100644
--- a/python/src/com/jetbrains/commandInterface/gnuCommandLine/CommandLineFileTypeFactory.java
+++ b/python/src/com/jetbrains/commandInterface/commandLine/CommandLineFileTypeFactory.java
@@ -13,7 +13,7 @@
* See the License for the specific language governing permissions and
* limitations under the License.
*/
-package com.jetbrains.commandInterface.gnuCommandLine;
+package com.jetbrains.commandInterface.commandLine;
import com.intellij.openapi.fileTypes.FileTypeConsumer;
import com.intellij.openapi.fileTypes.FileTypeFactory;
diff --git a/python/src/com/jetbrains/commandInterface/gnuCommandLine/CommandLineInspection.java b/python/src/com/jetbrains/commandInterface/commandLine/CommandLineInspection.java
similarity index 97%
rename from python/src/com/jetbrains/commandInterface/gnuCommandLine/CommandLineInspection.java
rename to python/src/com/jetbrains/commandInterface/commandLine/CommandLineInspection.java
index edefebcf40d4..b863d19e9c27 100644
--- a/python/src/com/jetbrains/commandInterface/gnuCommandLine/CommandLineInspection.java
+++ b/python/src/com/jetbrains/commandInterface/commandLine/CommandLineInspection.java
@@ -13,13 +13,13 @@
* See the License for the specific language governing permissions and
* limitations under the License.
*/
-package com.jetbrains.commandInterface.gnuCommandLine;
+package com.jetbrains.commandInterface.commandLine;
import com.intellij.codeInspection.*;
import com.intellij.psi.PsiElement;
import com.intellij.psi.PsiElementVisitor;
import com.intellij.psi.util.PsiTreeUtil;
-import com.jetbrains.commandInterface.gnuCommandLine.psi.*;
+import com.jetbrains.commandInterface.commandLine.psi.*;
import com.jetbrains.commandInterface.command.Command;
import com.jetbrains.python.PyBundle;
import org.jetbrains.annotations.Nls;
diff --git a/python/src/com/jetbrains/commandInterface/gnuCommandLine/CommandLineLanguage.java b/python/src/com/jetbrains/commandInterface/commandLine/CommandLineLanguage.java
similarity index 94%
rename from python/src/com/jetbrains/commandInterface/gnuCommandLine/CommandLineLanguage.java
rename to python/src/com/jetbrains/commandInterface/commandLine/CommandLineLanguage.java
index 80a3ad568a46..659d6e9e31a1 100644
--- a/python/src/com/jetbrains/commandInterface/gnuCommandLine/CommandLineLanguage.java
+++ b/python/src/com/jetbrains/commandInterface/commandLine/CommandLineLanguage.java
@@ -13,7 +13,7 @@
* See the License for the specific language governing permissions and
* limitations under the License.
*/
-package com.jetbrains.commandInterface.gnuCommandLine;
+package com.jetbrains.commandInterface.commandLine;
import com.intellij.lang.Language;
diff --git a/python/src/com/jetbrains/commandInterface/gnuCommandLine/CommandLineOptionReference.java b/python/src/com/jetbrains/commandInterface/commandLine/CommandLineOptionReference.java
similarity index 93%
rename from python/src/com/jetbrains/commandInterface/gnuCommandLine/CommandLineOptionReference.java
rename to python/src/com/jetbrains/commandInterface/commandLine/CommandLineOptionReference.java
index 43865754561f..7f40960d231a 100644
--- a/python/src/com/jetbrains/commandInterface/gnuCommandLine/CommandLineOptionReference.java
+++ b/python/src/com/jetbrains/commandInterface/commandLine/CommandLineOptionReference.java
@@ -13,12 +13,12 @@
* See the License for the specific language governing permissions and
* limitations under the License.
*/
-package com.jetbrains.commandInterface.gnuCommandLine;
+package com.jetbrains.commandInterface.commandLine;
import com.intellij.codeInsight.lookup.LookupElementBuilder;
import com.intellij.psi.PsiElement;
import com.jetbrains.commandInterface.command.Option;
-import com.jetbrains.commandInterface.gnuCommandLine.psi.CommandLineOption;
+import com.jetbrains.commandInterface.commandLine.psi.CommandLineOption;
import org.jetbrains.annotations.NotNull;
import org.jetbrains.annotations.Nullable;
diff --git a/python/src/com/jetbrains/commandInterface/gnuCommandLine/CommandLineParserDefinition.java b/python/src/com/jetbrains/commandInterface/commandLine/CommandLineParserDefinition.java
similarity index 91%
rename from python/src/com/jetbrains/commandInterface/gnuCommandLine/CommandLineParserDefinition.java
rename to python/src/com/jetbrains/commandInterface/commandLine/CommandLineParserDefinition.java
index 6bb73ead2cd1..ca1a2f7e7f53 100644
--- a/python/src/com/jetbrains/commandInterface/gnuCommandLine/CommandLineParserDefinition.java
+++ b/python/src/com/jetbrains/commandInterface/commandLine/CommandLineParserDefinition.java
@@ -13,7 +13,7 @@
* See the License for the specific language governing permissions and
* limitations under the License.
*/
-package com.jetbrains.commandInterface.gnuCommandLine;
+package com.jetbrains.commandInterface.commandLine;
import com.intellij.lang.ASTNode;
import com.intellij.lang.ParserDefinition;
@@ -27,8 +27,8 @@ import com.intellij.psi.PsiFile;
import com.intellij.psi.TokenType;
import com.intellij.psi.tree.IFileElementType;
import com.intellij.psi.tree.TokenSet;
-import com.jetbrains.commandInterface.gnuCommandLine.CommandLineElementTypes.Factory;
-import com.jetbrains.commandInterface.gnuCommandLine.psi.CommandLineFile;
+import com.jetbrains.commandInterface.commandLine.CommandLineElementTypes.Factory;
+import com.jetbrains.commandInterface.commandLine.psi.CommandLineFile;
import org.jetbrains.annotations.NotNull;
/**
diff --git a/python/src/com/jetbrains/commandInterface/gnuCommandLine/CommandLineParserUtil.java b/python/src/com/jetbrains/commandInterface/commandLine/CommandLineParserUtil.java
similarity index 97%
rename from python/src/com/jetbrains/commandInterface/gnuCommandLine/CommandLineParserUtil.java
rename to python/src/com/jetbrains/commandInterface/commandLine/CommandLineParserUtil.java
index 7469ab27019e..1bbbf5533ff3 100644
--- a/python/src/com/jetbrains/commandInterface/gnuCommandLine/CommandLineParserUtil.java
+++ b/python/src/com/jetbrains/commandInterface/commandLine/CommandLineParserUtil.java
@@ -13,7 +13,7 @@
* See the License for the specific language governing permissions and
* limitations under the License.
*/
-package com.jetbrains.commandInterface.gnuCommandLine;
+package com.jetbrains.commandInterface.commandLine;
import com.intellij.lang.PsiBuilder;
import com.intellij.lang.parser.GeneratedParserUtilBase;
diff --git a/python/src/com/jetbrains/commandInterface/gnuCommandLine/CommandLinePart.java b/python/src/com/jetbrains/commandInterface/commandLine/CommandLinePart.java
similarity index 90%
rename from python/src/com/jetbrains/commandInterface/gnuCommandLine/CommandLinePart.java
rename to python/src/com/jetbrains/commandInterface/commandLine/CommandLinePart.java
index 8c24c4ade703..719b1b1f5245 100644
--- a/python/src/com/jetbrains/commandInterface/gnuCommandLine/CommandLinePart.java
+++ b/python/src/com/jetbrains/commandInterface/commandLine/CommandLinePart.java
@@ -13,11 +13,11 @@
* See the License for the specific language governing permissions and
* limitations under the License.
*/
-package com.jetbrains.commandInterface.gnuCommandLine;
+package com.jetbrains.commandInterface.commandLine;
import com.intellij.psi.PsiElement;
import com.jetbrains.commandInterface.command.Command;
-import com.jetbrains.commandInterface.gnuCommandLine.psi.CommandLineFile;
+import com.jetbrains.commandInterface.commandLine.psi.CommandLineFile;
import org.jetbrains.annotations.Nullable;
/**
diff --git a/python/src/com/jetbrains/commandInterface/gnuCommandLine/CommandLineReferenceContributor.java b/python/src/com/jetbrains/commandInterface/commandLine/CommandLineReferenceContributor.java
similarity index 94%
rename from python/src/com/jetbrains/commandInterface/gnuCommandLine/CommandLineReferenceContributor.java
rename to python/src/com/jetbrains/commandInterface/commandLine/CommandLineReferenceContributor.java
index fb182c719437..fa57a18e1185 100644
--- a/python/src/com/jetbrains/commandInterface/gnuCommandLine/CommandLineReferenceContributor.java
+++ b/python/src/com/jetbrains/commandInterface/commandLine/CommandLineReferenceContributor.java
@@ -13,12 +13,12 @@
* See the License for the specific language governing permissions and
* limitations under the License.
*/
-package com.jetbrains.commandInterface.gnuCommandLine;
+package com.jetbrains.commandInterface.commandLine;
import com.intellij.patterns.PlatformPatterns;
import com.intellij.psi.*;
import com.intellij.util.ProcessingContext;
-import com.jetbrains.commandInterface.gnuCommandLine.psi.*;
+import com.jetbrains.commandInterface.commandLine.psi.*;
import org.jetbrains.annotations.NotNull;
/**
diff --git a/python/src/com/jetbrains/commandInterface/gnuCommandLine/CommandLineSyntaxHighlighterFactory.java b/python/src/com/jetbrains/commandInterface/commandLine/CommandLineSyntaxHighlighterFactory.java
similarity index 98%
rename from python/src/com/jetbrains/commandInterface/gnuCommandLine/CommandLineSyntaxHighlighterFactory.java
rename to python/src/com/jetbrains/commandInterface/commandLine/CommandLineSyntaxHighlighterFactory.java
index c18f97d6ff6e..00e7e1adde9b 100644
--- a/python/src/com/jetbrains/commandInterface/gnuCommandLine/CommandLineSyntaxHighlighterFactory.java
+++ b/python/src/com/jetbrains/commandInterface/commandLine/CommandLineSyntaxHighlighterFactory.java
@@ -13,7 +13,7 @@
* See the License for the specific language governing permissions and
* limitations under the License.
*/
-package com.jetbrains.commandInterface.gnuCommandLine;
+package com.jetbrains.commandInterface.commandLine;
import com.intellij.lexer.FlexAdapter;
import com.intellij.lexer.Lexer;
diff --git a/python/src/com/jetbrains/commandInterface/gnuCommandLine/LookupWithIndentsBuilder.java b/python/src/com/jetbrains/commandInterface/commandLine/LookupWithIndentsBuilder.java
similarity index 98%
rename from python/src/com/jetbrains/commandInterface/gnuCommandLine/LookupWithIndentsBuilder.java
rename to python/src/com/jetbrains/commandInterface/commandLine/LookupWithIndentsBuilder.java
index c587d3994af5..0a921c9c295d 100644
--- a/python/src/com/jetbrains/commandInterface/gnuCommandLine/LookupWithIndentsBuilder.java
+++ b/python/src/com/jetbrains/commandInterface/commandLine/LookupWithIndentsBuilder.java
@@ -13,7 +13,7 @@
* See the License for the specific language governing permissions and
* limitations under the License.
*/
-package com.jetbrains.commandInterface.gnuCommandLine;
+package com.jetbrains.commandInterface.commandLine;
import com.intellij.codeInsight.completion.PrioritizedLookupElement;
import com.intellij.codeInsight.lookup.LookupElement;
diff --git a/python/src/com/jetbrains/commandInterface/gnuCommandLine/ValidationResult.java b/python/src/com/jetbrains/commandInterface/commandLine/ValidationResult.java
similarity index 92%
rename from python/src/com/jetbrains/commandInterface/gnuCommandLine/ValidationResult.java
rename to python/src/com/jetbrains/commandInterface/commandLine/ValidationResult.java
index 9af55fb69db1..fcacd0bd7b1d 100644
--- a/python/src/com/jetbrains/commandInterface/gnuCommandLine/ValidationResult.java
+++ b/python/src/com/jetbrains/commandInterface/commandLine/ValidationResult.java
@@ -13,14 +13,14 @@
* See the License for the specific language governing permissions and
* limitations under the License.
*/
-package com.jetbrains.commandInterface.gnuCommandLine;
+package com.jetbrains.commandInterface.commandLine;
import com.intellij.openapi.util.Pair;
import com.intellij.psi.PsiElement;
import com.jetbrains.commandInterface.command.Argument;
import com.jetbrains.commandInterface.command.Option;
-import com.jetbrains.commandInterface.gnuCommandLine.psi.CommandLineArgument;
-import com.jetbrains.commandInterface.gnuCommandLine.psi.CommandLineOption;
+import com.jetbrains.commandInterface.commandLine.psi.CommandLineArgument;
+import com.jetbrains.commandInterface.commandLine.psi.CommandLineOption;
import org.jetbrains.annotations.NotNull;
import org.jetbrains.annotations.Nullable;
diff --git a/python/src/com/jetbrains/commandInterface/gnuCommandLine/command_line.bnf b/python/src/com/jetbrains/commandInterface/commandLine/command_line.bnf
similarity index 68%
rename from python/src/com/jetbrains/commandInterface/gnuCommandLine/command_line.bnf
rename to python/src/com/jetbrains/commandInterface/commandLine/command_line.bnf
index 8f3b3d1a20ab..c26d14cffdc3 100644
--- a/python/src/com/jetbrains/commandInterface/gnuCommandLine/command_line.bnf
+++ b/python/src/com/jetbrains/commandInterface/commandLine/command_line.bnf
@@ -6,20 +6,20 @@
{
// All 3 elements should extend this class
- mixin("option|argument|command")="com.jetbrains.commandInterface.gnuCommandLine.CommandLineElement"
+ mixin("option|argument|command")="com.jetbrains.commandInterface.commandLine.CommandLineElement"
// And implement this interface
- implements("option|argument|command")="com.jetbrains.commandInterface.gnuCommandLine.CommandLinePart"
+ implements("option|argument|command")="com.jetbrains.commandInterface.commandLine.CommandLinePart"
- parserClass = 'com.jetbrains.commandInterface.gnuCommandLine.CommandLineParser'
- parserUtilClass="com.jetbrains.commandInterface.gnuCommandLine.CommandLineParserUtil"
- psiImplUtilClass="com.jetbrains.commandInterface.gnuCommandLine.psi.impl.CommandLinePsiImplUtils"
- psiPackage = 'com.jetbrains.commandInterface.gnuCommandLine.psi'
- psiImplPackage = 'com.jetbrains.commandInterface.gnuCommandLine.psi.impl'
+ parserClass = 'com.jetbrains.commandInterface.commandLine.CommandLineParser'
+ parserUtilClass="com.jetbrains.commandInterface.commandLine.CommandLineParserUtil"
+ psiImplUtilClass="com.jetbrains.commandInterface.commandLine.psi.impl.CommandLinePsiImplUtils"
+ psiPackage = 'com.jetbrains.commandInterface.commandLine.psi'
+ psiImplPackage = 'com.jetbrains.commandInterface.commandLine.psi.impl'
- elementTypeHolderClass = 'com.jetbrains.commandInterface.gnuCommandLine.CommandLineElementTypes'
+ elementTypeHolderClass = 'com.jetbrains.commandInterface.commandLine.CommandLineElementTypes'
psiClassPrefix = "CommandLine"
psiVisitorName = "CommandLineVisitor"
- elementTypeClass = 'com.jetbrains.commandInterface.gnuCommandLine.CommandLineElementType'
+ elementTypeClass = 'com.jetbrains.commandInterface.commandLine.CommandLineElementType'
tokens=[
diff --git a/python/src/com/jetbrains/commandInterface/gnuCommandLine/psi/CommandLineFile.java b/python/src/com/jetbrains/commandInterface/commandLine/psi/CommandLineFile.java
similarity index 92%
rename from python/src/com/jetbrains/commandInterface/gnuCommandLine/psi/CommandLineFile.java
rename to python/src/com/jetbrains/commandInterface/commandLine/psi/CommandLineFile.java
index fac537c4db90..7459b18cb716 100644
--- a/python/src/com/jetbrains/commandInterface/gnuCommandLine/psi/CommandLineFile.java
+++ b/python/src/com/jetbrains/commandInterface/commandLine/psi/CommandLineFile.java
@@ -13,17 +13,17 @@
* See the License for the specific language governing permissions and
* limitations under the License.
*/
-package com.jetbrains.commandInterface.gnuCommandLine.psi;
+package com.jetbrains.commandInterface.commandLine.psi;
import com.intellij.extapi.psi.PsiFileBase;
import com.intellij.openapi.fileTypes.FileType;
import com.intellij.openapi.util.Key;
import com.intellij.psi.FileViewProvider;
import com.intellij.psi.util.PsiTreeUtil;
-import com.jetbrains.commandInterface.gnuCommandLine.CommandLineLanguage;
+import com.jetbrains.commandInterface.commandLine.CommandLineLanguage;
import com.jetbrains.commandInterface.command.Command;
-import com.jetbrains.commandInterface.gnuCommandLine.CommandLinePart;
-import com.jetbrains.commandInterface.gnuCommandLine.ValidationResult;
+import com.jetbrains.commandInterface.commandLine.CommandLinePart;
+import com.jetbrains.commandInterface.commandLine.ValidationResult;
import org.jetbrains.annotations.NotNull;
import org.jetbrains.annotations.Nullable;
diff --git a/python/src/com/jetbrains/commandInterface/gnuCommandLine/psi/ValidationResultImpl.java b/python/src/com/jetbrains/commandInterface/commandLine/psi/ValidationResultImpl.java
similarity index 98%
rename from python/src/com/jetbrains/commandInterface/gnuCommandLine/psi/ValidationResultImpl.java
rename to python/src/com/jetbrains/commandInterface/commandLine/psi/ValidationResultImpl.java
index f0be669c61bf..97a457e4f8fb 100644
--- a/python/src/com/jetbrains/commandInterface/gnuCommandLine/psi/ValidationResultImpl.java
+++ b/python/src/com/jetbrains/commandInterface/commandLine/psi/ValidationResultImpl.java
@@ -13,13 +13,13 @@
* See the License for the specific language governing permissions and
* limitations under the License.
*/
-package com.jetbrains.commandInterface.gnuCommandLine.psi;
+package com.jetbrains.commandInterface.commandLine.psi;
import com.intellij.openapi.util.Pair;
import com.intellij.psi.PsiElement;
import com.intellij.psi.PsiWhiteSpace;
import com.intellij.util.containers.hash.HashMap;
-import com.jetbrains.commandInterface.gnuCommandLine.ValidationResult;
+import com.jetbrains.commandInterface.commandLine.ValidationResult;
import com.jetbrains.commandInterface.command.Argument;
import com.jetbrains.commandInterface.command.Command;
import com.jetbrains.commandInterface.command.Option;
diff --git a/python/src/com/jetbrains/commandInterface/gnuCommandLine/psi/impl/CommandLinePsiImplUtils.java b/python/src/com/jetbrains/commandInterface/commandLine/psi/impl/CommandLinePsiImplUtils.java
similarity index 91%
rename from python/src/com/jetbrains/commandInterface/gnuCommandLine/psi/impl/CommandLinePsiImplUtils.java
rename to python/src/com/jetbrains/commandInterface/commandLine/psi/impl/CommandLinePsiImplUtils.java
index d222ea39f2fc..a42883ca3eaa 100644
--- a/python/src/com/jetbrains/commandInterface/gnuCommandLine/psi/impl/CommandLinePsiImplUtils.java
+++ b/python/src/com/jetbrains/commandInterface/commandLine/psi/impl/CommandLinePsiImplUtils.java
@@ -13,16 +13,16 @@
* See the License for the specific language governing permissions and
* limitations under the License.
*/
-package com.jetbrains.commandInterface.gnuCommandLine.psi.impl;
+package com.jetbrains.commandInterface.commandLine.psi.impl;
import com.intellij.psi.PsiElement;
import com.jetbrains.commandInterface.command.Argument;
import com.jetbrains.commandInterface.command.Option;
-import com.jetbrains.commandInterface.gnuCommandLine.CommandLinePart;
-import com.jetbrains.commandInterface.gnuCommandLine.ValidationResult;
-import com.jetbrains.commandInterface.gnuCommandLine.psi.CommandLineArgument;
-import com.jetbrains.commandInterface.gnuCommandLine.psi.CommandLineFile;
-import com.jetbrains.commandInterface.gnuCommandLine.psi.CommandLineOption;
+import com.jetbrains.commandInterface.commandLine.CommandLinePart;
+import com.jetbrains.commandInterface.commandLine.ValidationResult;
+import com.jetbrains.commandInterface.commandLine.psi.CommandLineArgument;
+import com.jetbrains.commandInterface.commandLine.psi.CommandLineFile;
+import com.jetbrains.commandInterface.commandLine.psi.CommandLineOption;
import org.jetbrains.annotations.NonNls;
import org.jetbrains.annotations.NotNull;
import org.jetbrains.annotations.Nullable;
diff --git a/python/src/com/jetbrains/commandInterface/gnuCommandLine/psi/package-info.java b/python/src/com/jetbrains/commandInterface/commandLine/psi/package-info.java
similarity index 93%
rename from python/src/com/jetbrains/commandInterface/gnuCommandLine/psi/package-info.java
rename to python/src/com/jetbrains/commandInterface/commandLine/psi/package-info.java
index 488377e0eae0..de61f34cdcaa 100644
--- a/python/src/com/jetbrains/commandInterface/gnuCommandLine/psi/package-info.java
+++ b/python/src/com/jetbrains/commandInterface/commandLine/psi/package-info.java
@@ -20,4 +20,4 @@
* Warning: most files in this package is autogenerated. Do not touch them directly.
* @author Ilya.Kazakevich
*/
-package com.jetbrains.commandInterface.gnuCommandLine.psi;
\ No newline at end of file
+package com.jetbrains.commandInterface.commandLine.psi;
\ No newline at end of file
diff --git a/python/src/com/jetbrains/commandInterface/console/ArgumentHintLayer.java b/python/src/com/jetbrains/commandInterface/console/ArgumentHintLayer.java
index 373cab1169ca..b0f6f4924e26 100644
--- a/python/src/com/jetbrains/commandInterface/console/ArgumentHintLayer.java
+++ b/python/src/com/jetbrains/commandInterface/console/ArgumentHintLayer.java
@@ -28,8 +28,8 @@ import com.intellij.psi.util.PsiModificationTracker;
import com.intellij.psi.util.PsiModificationTracker.Listener;
import com.intellij.util.messages.MessageBusConnection;
import com.jetbrains.commandInterface.command.Argument;
-import com.jetbrains.commandInterface.gnuCommandLine.ValidationResult;
-import com.jetbrains.commandInterface.gnuCommandLine.psi.CommandLineFile;
+import com.jetbrains.commandInterface.commandLine.ValidationResult;
+import com.jetbrains.commandInterface.commandLine.psi.CommandLineFile;
import com.jetbrains.python.PyBundle;
import org.jetbrains.annotations.NotNull;
import org.jetbrains.annotations.Nullable;
diff --git a/python/src/com/jetbrains/commandInterface/console/CommandExecutor.java b/python/src/com/jetbrains/commandInterface/console/CommandExecutor.java
index 3d3334a85b51..cbe56d18bfcd 100644
--- a/python/src/com/jetbrains/commandInterface/console/CommandExecutor.java
+++ b/python/src/com/jetbrains/commandInterface/console/CommandExecutor.java
@@ -19,8 +19,8 @@ import com.intellij.openapi.module.Module;
import com.intellij.psi.PsiFileFactory;
import com.intellij.util.Consumer;
import com.jetbrains.commandInterface.command.Command;
-import com.jetbrains.commandInterface.gnuCommandLine.CommandLineLanguage;
-import com.jetbrains.commandInterface.gnuCommandLine.psi.CommandLineFile;
+import com.jetbrains.commandInterface.commandLine.CommandLineLanguage;
+import com.jetbrains.commandInterface.commandLine.psi.CommandLineFile;
import com.jetbrains.python.psi.PyUtil;
import org.jetbrains.annotations.NotNull;
diff --git a/python/src/com/jetbrains/commandInterface/console/CommandLineConsole.java b/python/src/com/jetbrains/commandInterface/console/CommandLineConsole.java
index 071ef1ff7bb4..9878fdaba38f 100644
--- a/python/src/com/jetbrains/commandInterface/console/CommandLineConsole.java
+++ b/python/src/com/jetbrains/commandInterface/console/CommandLineConsole.java
@@ -31,8 +31,8 @@ import com.intellij.ui.content.ContentManager;
import com.intellij.ui.content.impl.ContentImpl;
import com.intellij.util.Consumer;
import com.jetbrains.commandInterface.command.Command;
-import com.jetbrains.commandInterface.gnuCommandLine.CommandLineLanguage;
-import com.jetbrains.commandInterface.gnuCommandLine.psi.CommandLineFile;
+import com.jetbrains.commandInterface.commandLine.CommandLineLanguage;
+import com.jetbrains.commandInterface.commandLine.psi.CommandLineFile;
import com.jetbrains.python.psi.PyUtil;
import org.jetbrains.annotations.NotNull;
import org.jetbrains.annotations.Nullable;
diff --git a/python/src/com/jetbrains/commandInterface/package-info.java b/python/src/com/jetbrains/commandInterface/package-info.java
index 072fcc6b32d0..5cbe55cfc3f0 100644
--- a/python/src/com/jetbrains/commandInterface/package-info.java
+++ b/python/src/com/jetbrains/commandInterface/package-info.java
@@ -33,12 +33,12 @@
* {@link com.jetbrains.commandInterface.command} contains classes to describe commands, arguments and options.
* It is up to you where to obtain list of available commands, but you should implement {@link com.jetbrains.commandInterface.command.Command}
* first, and create list of it with arguments and options. See package info for more details
- * {@link com.jetbrains.commandInterface.gnuCommandLine} is language based on
+ * {@link com.jetbrains.commandInterface.commandLine} is language based on
* GNU command line representation.
* It has PSI, so it parses command lines into tree of PsiElements. But this package is not only for parsing:
* If you provide list of
- * {@link com.jetbrains.commandInterface.command.Command commands} to {@link com.jetbrains.commandInterface.gnuCommandLine.psi.CommandLineFile}
- * (see {@link com.jetbrains.commandInterface.gnuCommandLine.psi.CommandLineFile#setCommands(java.util.List)}), it will inject references
+ * {@link com.jetbrains.commandInterface.command.Command commands} to {@link com.jetbrains.commandInterface.commandLine.psi.CommandLineFile}
+ * (see {@link com.jetbrains.commandInterface.commandLine.psi.CommandLineFile#setCommands(java.util.List)}), it will inject references
* (to provide autocompletion) and activate inspection to validate options and arguments.
* {@link com.jetbrains.commandInterface.console} displays console-like interface at the bottom of the screen to give user
* ability to wotk with your command-line.
diff --git a/python/testSrc/com/jetbrains/commandInterface/gnuCommandLine/CommandLineArgsTest.java b/python/testSrc/com/jetbrains/commandInterface/commandLine/CommandLineArgsTest.java
similarity index 95%
rename from python/testSrc/com/jetbrains/commandInterface/gnuCommandLine/CommandLineArgsTest.java
rename to python/testSrc/com/jetbrains/commandInterface/commandLine/CommandLineArgsTest.java
index 9848010fedc9..dc9be94ac4a4 100644
--- a/python/testSrc/com/jetbrains/commandInterface/gnuCommandLine/CommandLineArgsTest.java
+++ b/python/testSrc/com/jetbrains/commandInterface/commandLine/CommandLineArgsTest.java
@@ -13,11 +13,11 @@
* See the License for the specific language governing permissions and
* limitations under the License.
*/
-package com.jetbrains.commandInterface.gnuCommandLine;
+package com.jetbrains.commandInterface.commandLine;
import com.intellij.openapi.util.Pair;
import com.jetbrains.commandInterface.command.Argument;
-import com.jetbrains.commandInterface.gnuCommandLine.psi.CommandLineFile;
+import com.jetbrains.commandInterface.commandLine.psi.CommandLineFile;
import com.jetbrains.python.fixtures.PyTestCase;
import org.jetbrains.annotations.NotNull;
import org.junit.Assert;
diff --git a/python/testSrc/com/jetbrains/commandInterface/gnuCommandLine/CommandLineInspectionTest.java b/python/testSrc/com/jetbrains/commandInterface/commandLine/CommandLineInspectionTest.java
similarity index 93%
rename from python/testSrc/com/jetbrains/commandInterface/gnuCommandLine/CommandLineInspectionTest.java
rename to python/testSrc/com/jetbrains/commandInterface/commandLine/CommandLineInspectionTest.java
index 1d17f701e68b..30d46039b4b3 100644
--- a/python/testSrc/com/jetbrains/commandInterface/gnuCommandLine/CommandLineInspectionTest.java
+++ b/python/testSrc/com/jetbrains/commandInterface/commandLine/CommandLineInspectionTest.java
@@ -13,10 +13,10 @@
* See the License for the specific language governing permissions and
* limitations under the License.
*/
-package com.jetbrains.commandInterface.gnuCommandLine;
+package com.jetbrains.commandInterface.commandLine;
import com.intellij.psi.PsiFile;
-import com.jetbrains.commandInterface.gnuCommandLine.psi.CommandLineFile;
+import com.jetbrains.commandInterface.commandLine.psi.CommandLineFile;
import com.jetbrains.python.fixtures.PyTestCase;
import org.junit.Assert;
diff --git a/python/testSrc/com/jetbrains/commandInterface/gnuCommandLine/CommandLineParserTest.java b/python/testSrc/com/jetbrains/commandInterface/commandLine/CommandLineParserTest.java
similarity index 93%
rename from python/testSrc/com/jetbrains/commandInterface/gnuCommandLine/CommandLineParserTest.java
rename to python/testSrc/com/jetbrains/commandInterface/commandLine/CommandLineParserTest.java
index cf7424ffb8bc..f14d8be5dcdc 100644
--- a/python/testSrc/com/jetbrains/commandInterface/gnuCommandLine/CommandLineParserTest.java
+++ b/python/testSrc/com/jetbrains/commandInterface/commandLine/CommandLineParserTest.java
@@ -13,13 +13,11 @@
* See the License for the specific language governing permissions and
* limitations under the License.
*/
-package com.jetbrains.commandInterface.gnuCommandLine;
+package com.jetbrains.commandInterface.commandLine;
import com.intellij.testFramework.ParsingTestCase;
-import com.jetbrains.python.PythonTestUtil;
-
/**
* Tests command line parser
diff --git a/python/testSrc/com/jetbrains/commandInterface/gnuCommandLine/CommandLineSuggestionTest.java b/python/testSrc/com/jetbrains/commandInterface/commandLine/CommandLineSuggestionTest.java
similarity index 97%
rename from python/testSrc/com/jetbrains/commandInterface/gnuCommandLine/CommandLineSuggestionTest.java
rename to python/testSrc/com/jetbrains/commandInterface/commandLine/CommandLineSuggestionTest.java
index 74baf12c3e09..362d14a466e7 100644
--- a/python/testSrc/com/jetbrains/commandInterface/gnuCommandLine/CommandLineSuggestionTest.java
+++ b/python/testSrc/com/jetbrains/commandInterface/commandLine/CommandLineSuggestionTest.java
@@ -13,7 +13,7 @@
* See the License for the specific language governing permissions and
* limitations under the License.
*/
-package com.jetbrains.commandInterface.gnuCommandLine;
+package com.jetbrains.commandInterface.commandLine;
import com.intellij.codeInsight.lookup.LookupElement;
import com.intellij.util.containers.HashSet;
diff --git a/python/testSrc/com/jetbrains/commandInterface/gnuCommandLine/CommandTestTools.java b/python/testSrc/com/jetbrains/commandInterface/commandLine/CommandTestTools.java
similarity index 96%
rename from python/testSrc/com/jetbrains/commandInterface/gnuCommandLine/CommandTestTools.java
rename to python/testSrc/com/jetbrains/commandInterface/commandLine/CommandTestTools.java
index e026f2c2823c..8df8c0864d23 100644
--- a/python/testSrc/com/jetbrains/commandInterface/gnuCommandLine/CommandTestTools.java
+++ b/python/testSrc/com/jetbrains/commandInterface/commandLine/CommandTestTools.java
@@ -13,14 +13,14 @@
* See the License for the specific language governing permissions and
* limitations under the License.
*/
-package com.jetbrains.commandInterface.gnuCommandLine;
+package com.jetbrains.commandInterface.commandLine;
import com.intellij.openapi.application.ApplicationManager;
import com.intellij.openapi.fileTypes.FileTypeManager;
import com.intellij.openapi.util.Pair;
import com.intellij.testFramework.fixtures.CodeInsightTestFixture;
import com.jetbrains.commandInterface.command.*;
-import com.jetbrains.commandInterface.gnuCommandLine.psi.CommandLineFile;
+import com.jetbrains.commandInterface.commandLine.psi.CommandLineFile;
import com.jetbrains.python.PythonTestUtil;
import org.easymock.EasyMock;
import org.jetbrains.annotations.NotNull;
diff --git a/python/src/com/jetbrains/commandInterface/gnuCommandLine/package-info.java b/python/src/com/jetbrains/commandInterface/commandLine/package-info.java
similarity index 81%
rename from python/src/com/jetbrains/commandInterface/gnuCommandLine/package-info.java
rename to python/src/com/jetbrains/commandInterface/commandLine/package-info.java
index d517145ead15..099239461356 100644
--- a/python/src/com/jetbrains/commandInterface/gnuCommandLine/package-info.java
+++ b/python/src/com/jetbrains/commandInterface/commandLine/package-info.java
@@ -26,9 +26,9 @@
*
* PSI
* Generation based on Grammar-Kit, see .bnf file, do not edit parser nor lexer manually.
* When parsed, {@link com.jetbrains.commandInterface.gnuCommandLine.psi.CommandLineFile} is root element for
* {@link com.jetbrains.commandInterface.gnuCommandLine.CommandLineLanguage}.
* Warning: always fill {@link com.jetbrains.commandInterface.gnuCommandLine.psi.CommandLineFile#setCommands(java.util.List)}
* if possible.
*
* Extension points
@@ -37,4 +37,4 @@
*
* @author Ilya.Kazakevich
*/
-package com.jetbrains.commandInterface.gnuCommandLine;
\ No newline at end of file
+package com.jetbrains.commandInterface.commandLine;
\ No newline at end of file
@@ -26,9 +26,9 @@
* PSI
* Generation based on Grammar-Kit, see .bnf file, do not edit parser nor lexer manually.
- * When parsed, {@link com.jetbrains.commandInterface.gnuCommandLine.psi.CommandLineFile} is root element for
- * {@link com.jetbrains.commandInterface.gnuCommandLine.CommandLineLanguage}.
- * Warning: always fill {@link com.jetbrains.commandInterface.gnuCommandLine.psi.CommandLineFile#setCommands(java.util.List)}
+ * When parsed, {@link com.jetbrains.commandInterface.commandLine.psi.CommandLineFile} is root element for
+ * {@link com.jetbrains.commandInterface.commandLine.CommandLineLanguage}.
+ * Warning: always fill {@link com.jetbrains.commandInterface.commandLine.psi.CommandLineFile#setCommands(java.util.List)}
* if possible.
*
diff --git a/python/src/com/jetbrains/commandInterface/gnuCommandLine/psi/impl/package-info.java b/python/src/com/jetbrains/commandInterface/commandLine/psi/impl/package-info.java
similarity index 86%
rename from python/src/com/jetbrains/commandInterface/gnuCommandLine/psi/impl/package-info.java
rename to python/src/com/jetbrains/commandInterface/commandLine/psi/impl/package-info.java
index 7b45d7642752..2a9821b009da 100644
--- a/python/src/com/jetbrains/commandInterface/gnuCommandLine/psi/impl/package-info.java
+++ b/python/src/com/jetbrains/commandInterface/commandLine/psi/impl/package-info.java
@@ -16,9 +16,9 @@
/**
* Gnu command line language PSI implementation.
* Do not use this package directly, consider using interfaces from {@link com.jetbrains.commandInterface.gnuCommandLine.psi} instead.
* Warning: most files in this package is autogenerated. Do not touch them directly.
*
* @author Ilya.Kazakevich
*/
-package com.jetbrains.commandInterface.gnuCommandLine.psi.impl;
\ No newline at end of file
+package com.jetbrains.commandInterface.commandLine.psi.impl;
\ No newline at end of file
@@ -16,9 +16,9 @@
/**
* Gnu command line language PSI implementation.
- * Do not use this package directly, consider using interfaces from {@link com.jetbrains.commandInterface.gnuCommandLine.psi} instead.
+ * Do not use this package directly, consider using interfaces from {@link com.jetbrains.commandInterface.commandLine.psi} instead.
* Warning: most files in this package is autogenerated. Do not touch them directly.
*